#
# spec file for package libzdb
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         libsoname       %{name}13
Name:           libzdb
Version:        3.2.3
Release:        1.3
Summary:        Zild Database Library
License:        GPL-3.0-or-later
Group:          System/Libraries
URL:            https://www.tildeslash.com/libzdb/
Source0:        http://www.tildeslash.com/%{name}/dist/%{name}-%{version}.tar.gz
BuildRequires:  flex
BuildRequires:  mysql-devel
BuildRequires:  openssl-devel
BuildRequires:  pkgconfig
BuildRequires:  postgresql-devel
BuildRequires:  re2c
BuildRequires:  sqlite3-devel

%description
The Zild Database Library implements a small, fast, and easy to use
database API with thread-safe connection pooling. The library can connect
transparently to multiple database systems, has zero configuration and
connections are specified via a standard URL scheme.

%package -n %{libsoname}
Summary:        Shared library for libzdb
Group:          System/Libraries
Provides:       libzdb

%description -n %{libsoname}
Zild Database Library

This package contains the shared libzdb library

%package devel
Summary:        Development files for libzdb
Group:          Development/Libraries/C and C++
Requires:       %{libsoname} = %{version}

%description devel
The libraries and header files for developing applications that use libzdb

%prep
%setup -q

%build
%configure \
  --disable-static \
  --enable-openssl \
  --enable-sqliteunlock \
  --enable-protected
%make_build

%install
%make_install
# remove static libs
find %{buildroot} -type f -name "*.la" -delete -print

%post   -n %{libsoname} -p /sbin/ldconfig
%postun -n %{libsoname} -p /sbin/ldconfig

%files -n %{libsoname}
%license COPYING
%doc AUTHORS CHANGES README
%{_libdir}/%{name}.so.*

%files devel
%{_libdir}/%{name}.so
%{_libdir}/pkgconfig/zdb.pc
%{_includedir}/*

%changelog
* Thu Apr 11 2024 Georg Pfuetzenreuter <mail+rpm@georg-pfuetzenreuter.net>
- Update to 3.2.3:
  * New: Provide better error reporting if a Connection cannot be obtained from the Connection Pool.
  * Fixed: In C++, added a guard against stopping the Connection Pool with live active Connections
    to prevent a dealloc sequence problem.
  * Fixed: Plus many more minor improvements and fixes
* Thu Feb  4 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 3.2.2. Changes since 3.1:
  * Fix: Removed Thread.h from the API.
  * New: C++17 support via zdbpp.h which is distributed with libzdb
  for more idiomatic use of libzdb from C++.
  * New: Support prefetch rows for MySQL and Oracle. Either
    programatically via Connection_setFetchSize() or via
    ResultSet_setFetchSize() or via a new global 'fetch-size'
    URL option.
  * New: MySQL 5.7 and later. Added session query timeout accessible via
    Connection_setQueryTimeout()
  * New: MySQL 8. Added a new URL option 'auth-plugin' which specify
    the authentication plugin to use when connecting to a MySQL server.
  * New: Oracle: Added a new URL option 'sysdba' for connecting with
    sysdba privileges.
  * Fixed: Revert previous fix and remove last SQL terminator character ';' in
    statements, except if preceded with END; to allow for ending a pl/sql block.
  * Fixed: Oracle: Set SQL null value in prepared statement
  * Fixed: Oracle: Handle date/time literal values
* Sat Apr  2 2016 mpluskal@suse.com
- Update to 3.1
  * New: Support Literal IPv6 Addresses in the Database Connection
    URL. Ref. RFC2732
  * New: Honour timezone information if provided with date-time
    column values in Result Sets
  * Fixed: Issue #7 Removed onstop handler
  * Fixed: #8 Do not remove trailing SQL termination charachter ';'
    from statement
- Small spec file cleanup
- Enable openssl and sqliteunlock
- Update dependencies
* Sat Mar 22 2014 chris@computersalat.de
- fix LICENSE: GPL-3.0 -> GPL-3.0+
- fix subpkg and deps
  * add libsoname
  * devel requires libsoname(libzdb11) and not name(libzdb)
- fix configure
  * --disable-static
- add changes file
* Tue Mar 11 2014 bajizs@cnt.rs
- Version update 3.0
* Thu Dec 26 2013 bajizs@cnt.rs
- Version update 2.12
* Fri Apr 26 2013 bajizs@cnt.rs
- Version update 2.11.2
* Sun Aug 14 2011 bajizs@cnt.rs
- Initial package 2.8.1
